; This file is generated by the program tools/tools/validating-html-mirroring-from-dtd/laml-mirror-via-dtd.scm. Do not edit!

;;;; This is an accurate mirror of XHMTL1.0 (strict) which can perform full HTML validation on the fly, while generating the HTML output. The HTML output is an instance of an abstract syntax tree, which must be transformed to a string by means of the function <kbd>render</kbd>. <p>A surface form has a very flexible syntactic composition. Use the surface forms when you write an HTML document in LAML syntax. Each function in this file mirrors and generates an HTML element instance. The general form of a surface mirror function is <pre>   (tag 'a1 "v1" 'a2 "v2" ... 'am "vm" contents-1 contents-2 ... contents-n). </pre>where, in the most common case, <kbd>contents-1</kbd>, <kbd>contents-2</kbd> through <kbd>contents-n</kbd> are content constituents, such as strings or other HTML element instances. From LAML version 16.2 <kbd>contents-i</kbd> (i from 1 to n) can also be proper lists. The attribute names must be symbols, and the attribute values have to be strings.<p>The expression from above corresponds to the HTML tag <pre>   &lt;tag a1 "v1" a2 "v2" ... am "vm"&gt; contents-1 contents-2 ... contents-n &lt;/tag&gt;</pre>In the Scheme form it is possible to have attributes between and after the textual content. Attributes prefixed with 'css:' are CSS style attributes.<p>As mentioned, the mirror functions accept lists nested to an arbitrary level. Such lists are processed recursively (from LAML version 17.0). It means that you can pass lists of content constituents, or even lists with attribute names and values to the mirror functions.<p>Unless stated otherwise there will be a space character between contents constituents such as in between <kbd>contents-1</kbd> and <kbd>contents-2</kbd>. A boolean value false in between the contents elements suppresses white space in between them. This is in particular useful before punctuation characters. For convenience, we have bound the value #f to the variable '_'. <p>If the boolean variable <kbd>check-html-attributes?</kbd> is true the functions check the attributes of the tag against the attribute definitions in the document type definition. If the boolean variable <kbd>validate-html?</kbd> is true the mirror functions perform a <b>full HTML validity check.</b> Additional validation of context sensitive aspects (impossible to check via an XML DTD) is controlled by the variable <kbd>check-element-prohibitions?</kbd>. If the variable <kbd>transliterate-character-data?</kbd> is true, all character data are transformed via the the HTML character transformation table. These three variables are defined in the <a href = "basis.html#SECTION2">configuration part of the basic library</a>. Here you will also find definitions that control the handling of errors.<p>The HTML mirror functions emit abstract syntax trees, and not HTML code represented as strings. You should apply the function <kbd>render</kbd> to get a HTML string. The function <kbd>write-html</kbd> from the <kbd>laml.scm</kbd> file is helpful when rendering, linearizing, writing or pretty printing an AST to a text file. Notice that pretty printing may be quite expensive compared with the linearization as such.<p>The surface library requries the accompanying <a href = "basis.html">basic form library</a>, which contains the following sections of relevance for the surface mirror: XML and document type declarations, Configuration part (boolean control variables), and the rendering procedures. <p>Notice that the Scheme function <kbd>map</kbd> and the HTML element <kbd>map</kbd> give a name collision. We prefix the HTML element with 'html:' when applied as a HTML mirror function in LAML.<p>Currently, there is only a very small convenience library of the XHTML mirror.

; Constants:

(define explicit-space #t)
(define explicit-space-suppress #f)

;; The symbolic name of explicit white space suppress
(define _ explicit-space-suppress)

; ---------------------------------------------------------------------------------------------------
;;; AST functions.
;;; In this section we document the functions that work on abstract syntax trees.
;;; All the HTML mirror functions return abstract syntax trees, which need to be transformed
;;; to text before they can be presented. The function render performs this transformation.

;; A boolean variable that controls whether or not we check the internal soundness of ASTs.
;; If the basic mirror is used directly, it makes good sense to set this variable to #t.
;; Else we recommend a #f value.
(define check-ast-constituents? #f)

;; Make an AST given element-name, contents, and a property list of attributes.
;; Kind is either the symbol double or single.
;; The parameter contents may be a list of subtrees. It may also be or an element which satisfies
;; either ast?, cdata? or forced-white-space?. In these cases, we embed the single element into a list.
(define (make-ast element-name contents attributes kind)
 (let ((subtrees (cond ((ast? contents) (list contents))
                       ((cdata? contents) (list contents))
                       ((forced-white-space? contents) (list contents))
                       ((if check-ast-constituents? (ast-contents-list? contents) (list? contents)) contents)
                       (laml-error "make-ast: Contents must be ast, cdata, forced white space, or a list of these: " 
                          (as-string contents)))))
  (list 'ast (as-string element-name) subtrees attributes (as-symbol kind))))

(define (ast-contents-list? lst)
 (cond ((null? lst) #t)
       ((or (ast? (car lst)) (cdata? (car lst))
            (forced-white-space? (car lst)))
          (ast-contents-list? (cdr lst)))
       (else #f)))

;; Is the parameter x an AST
(define (ast? x)
  (and (pair? x) (eq? (car x) 'ast)
       (list? x) (= 5 (length x))))

;; Is the parameter x CDATA
;; .form (cdata? x)
(define cdata? string?)

; Is the parameter x either an ast or a contents string.
(define (contents-data? x)
 (or (cdata? x) (ast? x)))

;; Is the parameter x a white space mark.
(define (forced-white-space? x)
 (and (boolean? x) x))

(define white-space-related? boolean?)
 
;; Return the root element name of ast.
;; .pre-condition ast is an abstract syntax tree that satisfies the ast? predicate
(define (ast-element-name ast)
  (cadr ast))

;; Return the list of substrees of ast.
;; .pre-condition ast is an abstract syntax tree that satisfies  the ast? predicate
(define (ast-subtrees ast)
  (caddr ast))

;; Return the list of attributes of ast, on property list format.
;; .pre-condition ast is an abstract syntax tree that satisfies  the ast? predicate
(define (ast-attributes ast)
  (cadddr ast))

;; Return the kind of the ast. It is either the symbol single or double.
;; Tells whether the ast is to be rendered as a single or double tag in HTML.
;; .pre-condition ast is an abstract syntax tree that satisfies  the ast? predicate
(define (ast-kind ast)
  (fifth ast))

; ------------------------------------------------------------------------------------------

(define (sort-tag-parameters parameters tag-name)
 (sort-tag-parameters-1 parameters parameters '() '() tag-name))

(define (sort-tag-parameters-1 original-parameters parameters contents attributes tag-name)
 (letrec ((strip-initial-explicit-spaces 
	   (lambda (cl) (if (and (pair? cl) (eq? (car cl) explicit-space)) (strip-initial-explicit-spaces (cdr cl)) cl)))
	  (list-non-ast? (lambda (x) (and (list? x) (not (ast? x)))))
         )
  (cond ((null? parameters) (cons (reverse (strip-initial-explicit-spaces contents)) (reverse attributes)))

        ; CONTENTS DATA -  no space after
        ((and (contents-data? (car parameters)) (not (null? (cdr parameters)))
              (boolean? (cadr parameters)) (not (cadr parameters)))              
                 (sort-tag-parameters-1 original-parameters (cddr parameters) (cons (car parameters) contents) attributes tag-name))

        ; CONTENTS DATA -  space after
        ((and (contents-data? (car parameters)) (not (null? (cdr parameters)))
              (boolean? (cadr parameters)) (cadr parameters))                    ; space after
                 (sort-tag-parameters-1 original-parameters
                                        (cddr parameters) (cons explicit-space (cons (car parameters) contents)) attributes tag-name))

        ; CONTENTS DATA -  space after
        ((contents-data? (car parameters))   ; space after
                 (sort-tag-parameters-1 original-parameters 
                                        (cdr parameters) (cons explicit-space (cons (car parameters) contents)) attributes tag-name))


        ; LIST - no space after
        ((and (list-non-ast? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (not (cadr parameters)))
           (let* ((rec-res (sort-tag-parameters-1 original-parameters (car parameters) '() '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )  
              (sort-tag-parameters-1 original-parameters
                                        (cddr parameters) 
                                        (append (reverse rec-contents) contents) (append (reverse rec-attributes) attributes) tag-name)))

        ; LIST - space after
        ((and (list-non-ast? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters))  (cadr parameters))
           (let* ((rec-res (sort-tag-parameters-1 original-parameters (car parameters) '() '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )  
              (sort-tag-parameters-1 original-parameters
                                        (cddr parameters) 
                                        (append (list explicit-space) (reverse rec-contents) contents) 
                                        (append (reverse rec-attributes) attributes) tag-name)))

        ; LIST - space after
        ((and (list-non-ast? (car parameters)))
           (let* ((rec-res (sort-tag-parameters-1 original-parameters (car parameters) '() '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 ) 
              (sort-tag-parameters-1 original-parameters
                                        (cdr parameters) 
                                        (append (list explicit-space)
                                                (reverse rec-contents)
                                                contents)
                                        (append (reverse rec-attributes) attributes) tag-name)))

        ; SYMBOL - attribute name 
        ((and (symbol? (car parameters)) (not (null? (cdr parameters))) (not (boolean? (cadr parameters))))
           (let ((attr-name (car parameters))
                 (attr-val (cadr parameters)))
             (sort-tag-parameters-1 original-parameters (cddr parameters) contents (cons attr-val (cons attr-name attributes)) tag-name)))

        ; SYMBOL - error
        ((symbol? (car parameters)) (sort-error (string-append "Attributes of the " tag-name
                                    " tag must be of the form 'symbol \"value\". Only the symbol " (as-string (car parameters))
                                    " appears in last attribute") original-parameters))

        (else (sort-error (string-append "Error in an LAML " tag-name " tag.") original-parameters))
  )))

; -----------------------------------------------------------------------------------------------------------------------




; Return an HTML mirror surface function, in which textual content parameters and attribute
; value pairs can be given in a very liberal fashion.
; html-basic-function is the name of an HTML basic mirror function to be called once we have
; sorted out contents and attributes of the present form.
; Tag-name is a string which represents the name of the tag (used for error message purposes).
; single-double-kind is either the symbol single, double or possible-single.
; The generated surface function is made efficient (avoiding parameter sorting) in the following special cases:
; (1) single-tag, no attributes.
; (2) double-tag, one string contents parameter.
(define (generate-html-surface-function html-basic-function tag-name single-double-kind)
 (cond ((eq? single-double-kind 'double)
          (lambda parameters
            (if (and (pair? parameters) (string? (car parameters)) (null? (cdr parameters)))
                (apply html-basic-function (cons (car parameters) '())) ; efficient handling of double tag with 
                                                                        ; a single string contents parameter
                (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
		       (contents (car contents-attributes))
		       (attributes (cdr contents-attributes))
                      )
		  (apply html-basic-function (cons contents attributes)))
            )
          )
       )

       ((eq? single-double-kind 'single)   
          (lambda parameters
            (if (null? parameters)
                (apply html-basic-function '())  ; efficient handling of single tag with no attributes
                (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
		       (contents (car contents-attributes))
		       (attributes (cdr contents-attributes))
                      )
		  (check-for-empty-contents! contents tag-name)
		  (apply html-basic-function attributes))
            )
          )
       )

       ((eq? single-double-kind 'possible-single)   
          (lambda parameters
            (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
                   (contents (car contents-attributes))
                   (attributes (cdr contents-attributes))
                  )
               (if (null? contents) ; generate single tag
                   (apply html-basic-function (cons #f attributes))
                   (apply html-basic-function (cons contents attributes))
               )
            )
          )
       )

       (else (error (string-append "generate-html-surface-function: unknown single-double-kind: " (as-string single-double-kind))))
 )
)

(define (check-for-empty-contents! contents tag-name)
  (if (not (null? contents))
      (display-warning (string-append "The single tag " tag-name " is not supposed to have any contents: " (as-string contents) ". We just skip it."))))



; Return the string corresponding to the element contents of lst.
; As of this version, no kinds of white space is added automatically.
(define (list-to-element-contents lst)
  (apply string-append lst))

(define (sort-error message parameters)
 (let* ((max-str-lgt 80)  ; symbolic constant definition
        (parameters-1 (as-quoted-string parameters))
        (parameters-2 (if (> (string-length parameters-1) max-str-lgt) 
                        (string-append (substring parameters-1 0 (- max-str-lgt 1)) "...")
                        parameters-1)))
  (error
    (string-append
      message (as-string #\newline)
      "  FORM CONTENTS AND ATTR.: " parameters-2 (as-string #\newline)))))
      

;;; Other useful functions. 
;;; In this section there are non-mirror functions which are useful in surface HTML forms.

;; A non-HTML tag which concatenates parameters of a form to a single string. 
;; There may be boolean values among the parameters.
;; A boolean false after a textual contents string suppresses white space after the contents string.
;; Warn if there are attributes among the parameters. Possible attributes are just skipped.
(define (concatenate . parameters)
  (let* ((res-pair (sort-tag-parameters parameters "concatenate function"))
         (contents (car res-pair))
         (attributes (cdr res-pair)))
    (if (not (null? attributes))
        (display-warning 
          (string-append "There are attribute value pairs in a context assumed to pure textual contents: " (as-string attributes) ". "
                         "I just discarded these.")))
    contents))
 

;; Generate a HTML tag application for tag-name with attributes and contents
;; given by parameters. The parameters obey the syntax of a the LAML surface forms.
;; This function is useful for generation of non-standard tag applications.
(define (free-html-element tag-name . parameters)
 (let* ((cont-attr (sort-tag-parameters parameters tag-name))
        (cont (car cont-attr))
        (attr (cdr cont-attr)))
   (if (empty-string? cont)
       (terminal-ast-node tag-name attr)
       (internal-ast-node tag-name cont attr))))

;; Generate a HTML tag application for tag-name with attributes and contents given by parameters.
;; This function corresponds exactly to free-html-element; however, this function takes exactly two
;; parameters whereas free-html-element takes one or more parameters.
(define (free-html-element-1 tag-name parameters)
 (let* ((cont-attr (sort-tag-parameters parameters tag-name))
        (cont (car cont-attr))
        (attr (cdr cont-attr)))
   (if (empty-string? cont)
       (terminal-ast-node tag-name attr)
       (internal-ast-node tag-name cont attr))))

;; Define partial attributes and element contents of element and return a new element function
;; with the attributes and contents partially fixed.
;; attributes-and-contents is of the same form as the parameters to a LAML surface mirror functions.
;; In fact, attributes-and-contents are just appended to the actual parameters to the modified.
;; .example (define a-main (modify-element a 'target "main"))
;; .returns an attribute-modified mirror function
(define (modify-element element . attributes-and-contents)
  (lambda parameters (apply element (append parameters attributes-and-contents))))

;; Convert an abtract syntax tree to a parse tree.
;; Abstract syntax trees are produced by the validating mirror functions.
;; Parse trees are used as an internal format in the HTML and the XML pretty printing procedures.
;; You can use the function pretty-print-html-parse-tree on the parse tree returned by ast-to-parse-tree.
;; .pre-condition The LAML tool html-support (for parsing and pretty printing) must be loaded for this function to work.
;; .misc To load html-support: <kbd>(laml-tool-load "xml-html-support/html-support.scm")</kbd>
(define (ast-to-parse-tree ast)
 (let ((pt (ast-to-parse-tree-1 ast)))
   (make-final-parse-tree 'html-tree (list pt))))


; The function doing the real work in the ast to parse tree conversion.
(define (ast-to-parse-tree-1 ast)
 (letrec 
  ((subtree-transform     ; the function doing the overall ast to parse tree transformation
    (lambda (x) 
     (cond ((ast? x) (ast-to-parse-tree-1 x))
	   ((cdata? x) x)
	   ((forced-white-space? x) " ")
	   (else (laml-error "subtree-transform:" "Unknown subtree constituent" (as-string x)))))
    )

   (explicit-space-splicing  ; join explicit spaces, " ", to the left string constituent - to avoid empty lines after pretty printing.
     (lambda (parse-tree)
       (if (tree-entry? parse-tree)
           (let* ((node (root-of-parse-tree parse-tree))
                  (subtrees (subtrees-of-parse-tree parse-tree))
                  (new-subtrees (explicit-space-splicing-lst subtrees '()))
                 )
             (make-parse-tree node new-subtrees))
           parse-tree)
      ))

   (explicit-space-splicing-lst
     (lambda (subtree-list res-lst)
       (cond ((null? subtree-list)
                  (reverse res-lst))
             ((null? (cdr subtree-list))   ; only a single element left - get finished
                (explicit-space-splicing-lst (cdr subtree-list) (cons (car subtree-list) res-lst)))
             ((and (string? (car subtree-list)) (string? (cadr subtree-list)))   ; interesting case - there are two elements
                (if (equal? (cadr subtree-list) " ")    ; join car and cadr via string-append
                    (explicit-space-splicing-lst (cddr subtree-list) (cons (string-append (car subtree-list) (cadr subtree-list)) res-lst))
                    (explicit-space-splicing-lst (cdr subtree-list) (cons (car subtree-list) res-lst))))
             (else (explicit-space-splicing-lst (cdr subtree-list) (cons (car subtree-list) res-lst))))))

   (split-attribute-list  ; split in html and css attributes
     (lambda (attr-lst) (split-attribute-list-1 attr-lst '() ())))

   (split-attribute-list-1  ; iterative helping function
     (lambda (attr-lst html-attr-list css-attr-list)
       (cond ((null? attr-lst) (cons (reverse html-attr-list) (reverse css-attr-list)))
             ((css-key? (car attr-lst)) 
                (split-attribute-list-1 (cddr attr-lst) html-attr-list (cons (cadr attr-lst) (cons (car attr-lst) css-attr-list))))
             (else 
                (split-attribute-list-1 (cddr attr-lst) (cons (cadr attr-lst) (cons (car attr-lst) html-attr-list)) css-attr-list)))))

   (to-css-string     ; linearize all css attributes to a single string
     (lambda (css-attr-list)
       (let ((css-attr-alist (propertylist-to-alist css-attr-list)))
        (string-append
         (list-to-string 
          (map 
           (lambda (css-key-val) (linearize-attribute-pair-css (cdr css-key-val) (css-key? (car css-key-val))))
           css-attr-alist)
          ";") ";"))))

   )
   (let* ((element-name (ast-element-name ast))
 	  (subtrees (ast-subtrees ast))
	  (attr-lst (ast-attributes ast))  ; prop list format
          (attr-list-normal-css (split-attribute-list attr-lst))
          (html-attr-list (car attr-list-normal-css)) ; prop list format
          (css-attr-list (cdr attr-list-normal-css)) ; prop list format
          (attr-lst-result 
            (if (null? css-attr-list)
                html-attr-list
                (cons 'style (cons (to-css-string css-attr-list) html-attr-list))))
	  (kind (ast-kind ast))
   
	 )
     (cond ((eq? kind 'single)
              (make-tag-structure
	       'start-end
	       element-name 
	       attr-lst-result))
           ((eq? kind 'double)
              (explicit-space-splicing
               (make-parse-tree 
		(make-tag-structure
		 'start
		 element-name 
		 attr-lst-result)
		(map subtree-transform subtrees))))
           (else (laml-error "ast-to-parse-tree-1:" "Unknown kind of ast" kind))))))



    
  





;;; The HTML surface mirror functions

;; The LAML mirror of the XHMTL1.0 (strict) <b>td</b> double tag element . <br>
;; .form (td . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:td" "basis.html#xhtml1:td"
(define td (generate-html-surface-function xhtml1:td "td" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>th</b> double tag element . <br>
;; .form (th . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:th" "basis.html#xhtml1:th"
(define th (generate-html-surface-function xhtml1:th "th" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tr</b> double tag element . <br>
;; .form (tr . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (th | td)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tr" "basis.html#xhtml1:tr"
(define tr (generate-html-surface-function xhtml1:tr "tr" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>col</b> single tag element . <br>
;; .form (col . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:col" "basis.html#xhtml1:col"
(define col (generate-html-surface-function xhtml1:col "col" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>colgroup</b> double tag element . <br>
;; .form (colgroup . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br><p><font size = 2>Content model: (col)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:colgroup" "basis.html#xhtml1:colgroup"
(define colgroup (generate-html-surface-function xhtml1:colgroup "colgroup" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tbody</b> double tag element . <br>
;; .form (tbody . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (tr)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tbody" "basis.html#xhtml1:tbody"
(define tbody (generate-html-surface-function xhtml1:tbody "tbody" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tfoot</b> double tag element . <br>
;; .form (tfoot . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (tr)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tfoot" "basis.html#xhtml1:tfoot"
(define tfoot (generate-html-surface-function xhtml1:tfoot "tfoot" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>thead</b> double tag element . <br>
;; .form (thead . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (tr)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:thead" "basis.html#xhtml1:thead"
(define thead (generate-html-surface-function xhtml1:thead "thead" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>caption</b> double tag element . <br>
;; .form (caption . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:caption" "basis.html#xhtml1:caption"
(define caption (generate-html-surface-function xhtml1:caption "caption" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>table</b> double tag element . <br>
;; .form (table . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, summary, width, border, frame, rules, cellspacing, cellpadding. <br><p><font size = 2>Content model: (caption?, (col*|colgroup*), ((thead?, tfoot?, tbody+)|(tr+)))</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:table" "basis.html#xhtml1:table"
(define table (generate-html-surface-function xhtml1:table "table" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>button</b> double tag element . <br>
;; .form (button . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, value, type, disabled, tabindex, accesskey, onfocus, onblur. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | table | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:button" "basis.html#xhtml1:button"
(define button (generate-html-surface-function xhtml1:button "button" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>legend</b> double tag element . <br>
;; .form (legend . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, accesskey. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:legend" "basis.html#xhtml1:legend"
(define legend (generate-html-surface-function xhtml1:legend "legend" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>fieldset</b> double tag element . <br>
;; .form (fieldset . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | legend | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:fieldset" "basis.html#xhtml1:fieldset"
(define fieldset (generate-html-surface-function xhtml1:fieldset "fieldset" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>textarea</b> double tag element . <br>
;; .form (textarea . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: rows, cols. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, disabled, readonly, tabindex, accesskey, onfocus, onblur, onselect, onchange. <br><p><font size = 2>Content model: (#pcdata)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:textarea" "basis.html#xhtml1:textarea"
(define textarea (generate-html-surface-function xhtml1:textarea "textarea" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>option</b> double tag element . <br>
;; .form (option . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, selected, disabled, label, value. <br><p><font size = 2>Content model: (#pcdata)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:option" "basis.html#xhtml1:option"
(define option (generate-html-surface-function xhtml1:option "option" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>optgroup</b> double tag element . <br>
;; .form (optgroup . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: label. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, disabled. <br><p><font size = 2>Content model: (option)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:optgroup" "basis.html#xhtml1:optgroup"
(define optgroup (generate-html-surface-function xhtml1:optgroup "optgroup" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>select</b> double tag element . <br>
;; .form (select . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, size, multiple, disabled, tabindex, onfocus, onblur, onchange. <br><p><font size = 2>Content model: (optgroup | option)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:select" "basis.html#xhtml1:select"
(define select (generate-html-surface-function xhtml1:select "select" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>input</b> single tag element . <br>
;; .form (input . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, name, value, checked, disabled, readonly, size, maxlength, src, alt, usemap, tabindex, accesskey, onfocus, onblur, onselect, onchange, accept. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:input" "basis.html#xhtml1:input"
(define input (generate-html-surface-function xhtml1:input "input" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>label</b> double tag element . <br>
;; .form (label . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, for, accesskey, onfocus, onblur. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:label" "basis.html#xhtml1:label"
(define label (generate-html-surface-function xhtml1:label "label" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>form</b> double tag element . <br>
;; .form (form . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: action. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, method, enctype, onsubmit, onreset, accept, accept-charset. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:form" "basis.html#xhtml1:form"
(define form (generate-html-surface-function xhtml1:form "form" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>area</b> single tag element . <br>
;; .form (area . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: alt. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, shape, coords, href, nohref, tabindex, accesskey, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:area" "basis.html#xhtml1:area"
(define area (generate-html-surface-function xhtml1:area "area" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>xhtml:map</b> double tag element . <br>
;; .form (xhtml:map . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: name. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: ((p | h1|h2|h3|h4|h5|h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)+ | area+)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:map" "basis.html#xhtml1:map"
(define xhtml:map (generate-html-surface-function xhtml1:map "xhtml:map" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>img</b> single tag element . <br>
;; .form (img . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: src, alt. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, longdesc, height, width, usemap, ismap. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:img" "basis.html#xhtml1:img"
(define img (generate-html-surface-function xhtml1:img "img" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>param</b> single tag element . <br>
;; .form (param . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: name. <p>Optional attributes: id, value, valuetype, type. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:param" "basis.html#xhtml1:param"
(define param (generate-html-surface-function xhtml1:param "param" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>object</b> double tag element . <br>
;; .form (object . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, declare, classid, codebase, data, type, codetype, archive, standby, height, width, usemap, name, tabindex. <br><p><font size = 2>Content model: (#pcdata | param | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:object" "basis.html#xhtml1:object"
(define object (generate-html-surface-function xhtml1:object "object" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>small</b> double tag element . <br>
;; .form (small . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:small" "basis.html#xhtml1:small"
(define small (generate-html-surface-function xhtml1:small "small" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>big</b> double tag element . <br>
;; .form (big . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:big" "basis.html#xhtml1:big"
(define big (generate-html-surface-function xhtml1:big "big" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>b</b> double tag element . <br>
;; .form (b . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:b" "basis.html#xhtml1:b"
(define b (generate-html-surface-function xhtml1:b "b" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>i</b> double tag element . <br>
;; .form (i . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:i" "basis.html#xhtml1:i"
(define i (generate-html-surface-function xhtml1:i "i" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tt</b> double tag element . <br>
;; .form (tt . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:tt" "basis.html#xhtml1:tt"
(define tt (generate-html-surface-function xhtml1:tt "tt" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>sup</b> double tag element . <br>
;; .form (sup . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:sup" "basis.html#xhtml1:sup"
(define sup (generate-html-surface-function xhtml1:sup "sup" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>sub</b> double tag element . <br>
;; .form (sub . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:sub" "basis.html#xhtml1:sub"
(define sub (generate-html-surface-function xhtml1:sub "sub" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>q</b> double tag element . <br>
;; .form (q . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:q" "basis.html#xhtml1:q"
(define q (generate-html-surface-function xhtml1:q "q" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>acronym</b> double tag element . <br>
;; .form (acronym . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:acronym" "basis.html#xhtml1:acronym"
(define acronym (generate-html-surface-function xhtml1:acronym "acronym" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>abbr</b> double tag element . <br>
;; .form (abbr . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:abbr" "basis.html#xhtml1:abbr"
(define abbr (generate-html-surface-function xhtml1:abbr "abbr" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>cite</b> double tag element . <br>
;; .form (cite . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:cite" "basis.html#xhtml1:cite"
(define cite (generate-html-surface-function xhtml1:cite "cite" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>var</b> double tag element . <br>
;; .form (var . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:var" "basis.html#xhtml1:var"
(define var (generate-html-surface-function xhtml1:var "var" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>kbd</b> double tag element . <br>
;; .form (kbd . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:kbd" "basis.html#xhtml1:kbd"
(define kbd (generate-html-surface-function xhtml1:kbd "kbd" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>samp</b> double tag element . <br>
;; .form (samp . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:samp" "basis.html#xhtml1:samp"
(define samp (generate-html-surface-function xhtml1:samp "samp" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>code</b> double tag element . <br>
;; .form (code . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:code" "basis.html#xhtml1:code"
(define code (generate-html-surface-function xhtml1:code "code" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dfn</b> double tag element . <br>
;; .form (dfn . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dfn" "basis.html#xhtml1:dfn"
(define dfn (generate-html-surface-function xhtml1:dfn "dfn" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>strong</b> double tag element . <br>
;; .form (strong . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:strong" "basis.html#xhtml1:strong"
(define strong (generate-html-surface-function xhtml1:strong "strong" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>em</b> double tag element . <br>
;; .form (em . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:em" "basis.html#xhtml1:em"
(define em (generate-html-surface-function xhtml1:em "em" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>br</b> single tag element . <br>
;; .form (br . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:br" "basis.html#xhtml1:br"
(define br (generate-html-surface-function xhtml1:br "br" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>bdo</b> double tag element . <br>
;; .form (bdo . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: dir. <p>Optional attributes: id, class, style, title, lang, xml:lang. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:bdo" "basis.html#xhtml1:bdo"
(define bdo (generate-html-surface-function xhtml1:bdo "bdo" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>span</b> double tag element . <br>
;; .form (span . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:span" "basis.html#xhtml1:span"
(define span (generate-html-surface-function xhtml1:span "span" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>a</b> double tag element . <br>
;; .form (a . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir, id, class, style, title, charset, type, name, href, hreflang, rel, rev, accesskey, shape, coords, tabindex, onfocus, onblur. <br><p><font size = 2>Content model: (#pcdata | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:a" "basis.html#xhtml1:a"
(define a (generate-html-surface-function xhtml1:a "a" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>del</b> double tag element . <br>
;; .form (del . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:del" "basis.html#xhtml1:del"
(define del (generate-html-surface-function xhtml1:del "del" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>ins</b> double tag element . <br>
;; .form (ins . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:ins" "basis.html#xhtml1:ins"
(define ins (generate-html-surface-function xhtml1:ins "ins" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>blockquote</b> double tag element . <br>
;; .form (blockquote . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br><p><font size = 2>Content model: (p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:blockquote" "basis.html#xhtml1:blockquote"
(define blockquote (generate-html-surface-function xhtml1:blockquote "blockquote" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>pre</b> double tag element . <br>
;; .form (pre . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, xml:space. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | map | tt | i | b | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:pre" "basis.html#xhtml1:pre"
(define pre (generate-html-surface-function xhtml1:pre "pre" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>hr</b> single tag element . <br>
;; .form (hr . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:hr" "basis.html#xhtml1:hr"
(define hr (generate-html-surface-function xhtml1:hr "hr" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>address</b> double tag element . <br>
;; .form (address . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:address" "basis.html#xhtml1:address"
(define address (generate-html-surface-function xhtml1:address "address" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dd</b> double tag element . <br>
;; .form (dd . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dd" "basis.html#xhtml1:dd"
(define dd (generate-html-surface-function xhtml1:dd "dd" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dt</b> double tag element . <br>
;; .form (dt . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dt" "basis.html#xhtml1:dt"
(define dt (generate-html-surface-function xhtml1:dt "dt" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dl</b> double tag element . <br>
;; .form (dl . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (dt | dd)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:dl" "basis.html#xhtml1:dl"
(define dl (generate-html-surface-function xhtml1:dl "dl" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>li</b> double tag element . <br>
;; .form (li . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:li" "basis.html#xhtml1:li"
(define li (generate-html-surface-function xhtml1:li "li" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>ol</b> double tag element . <br>
;; .form (ol . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (li)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:ol" "basis.html#xhtml1:ol"
(define ol (generate-html-surface-function xhtml1:ol "ol" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>ul</b> double tag element . <br>
;; .form (ul . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (li)+</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:ul" "basis.html#xhtml1:ul"
(define ul (generate-html-surface-function xhtml1:ul "ul" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h6</b> double tag element . <br>
;; .form (h6 . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h6" "basis.html#xhtml1:h6"
(define h6 (generate-html-surface-function xhtml1:h6 "h6" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h5</b> double tag element . <br>
;; .form (h5 . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h5" "basis.html#xhtml1:h5"
(define h5 (generate-html-surface-function xhtml1:h5 "h5" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h4</b> double tag element . <br>
;; .form (h4 . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h4" "basis.html#xhtml1:h4"
(define h4 (generate-html-surface-function xhtml1:h4 "h4" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h3</b> double tag element . <br>
;; .form (h3 . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h3" "basis.html#xhtml1:h3"
(define h3 (generate-html-surface-function xhtml1:h3 "h3" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h2</b> double tag element . <br>
;; .form (h2 . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h2" "basis.html#xhtml1:h2"
(define h2 (generate-html-surface-function xhtml1:h2 "h2" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h1</b> double tag element . <br>
;; .form (h1 . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:h1" "basis.html#xhtml1:h1"
(define h1 (generate-html-surface-function xhtml1:h1 "h1" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>p</b> double tag element . <br>
;; .form (p . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:p" "basis.html#xhtml1:p"
(define p (generate-html-surface-function xhtml1:p "p" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>div</b> double tag element . <br>
;; .form (div . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:div" "basis.html#xhtml1:div"
(define div (generate-html-surface-function xhtml1:div "div" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>body</b> double tag element . <br>
;; .form (body . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, onload, onunload. <br><p><font size = 2>Content model: (p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:body" "basis.html#xhtml1:body"
(define body (generate-html-surface-function xhtml1:body "body" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>noscript</b> double tag element . <br>
;; .form (noscript . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)*</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:noscript" "basis.html#xhtml1:noscript"
(define noscript (generate-html-surface-function xhtml1:noscript "noscript" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>script</b> double tag element . <br>
;; .form (script . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: type. <p>Optional attributes: charset, src, defer, xml:space. <br><p><font size = 2>Content model: (#pcdata)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:script" "basis.html#xhtml1:script"
(define script (generate-html-surface-function xhtml1:script "script" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>style</b> double tag element . <br>
;; .form (style . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: type. <p>Optional attributes: lang, xml:lang, dir, media, title, xml:space. <br><p><font size = 2>Content model: (#pcdata)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:style" "basis.html#xhtml1:style"
(define style (generate-html-surface-function xhtml1:style "style" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>link</b> single tag element . <br>
;; .form (link . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, charset, href, hreflang, type, rel, rev, media. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:link" "basis.html#xhtml1:link"
(define link (generate-html-surface-function xhtml1:link "link" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>meta</b> single tag element . <br>
;; .form (meta . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: content. <p>Optional attributes: lang, xml:lang, dir, http-equiv, name, scheme. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:meta" "basis.html#xhtml1:meta"
(define meta (generate-html-surface-function xhtml1:meta "meta" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>base</b> single tag element . <br>
;; .form (base . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: href. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:base" "basis.html#xhtml1:base"
(define base (generate-html-surface-function xhtml1:base "base" (quote single)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>title</b> double tag element . <br>
;; .form (title . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir. <br><p><font size = 2>Content model: (#pcdata)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:title" "basis.html#xhtml1:title"
(define title (generate-html-surface-function xhtml1:title "title" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>head</b> double tag element . <br>
;; .form (head . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir, profile. <br><p><font size = 2>Content model: ((script|style|meta|link|object)*,      ((title, (script|style|meta|link|object)*, (base, (script|style|meta|link|object)*)?) |       (base, (script|style|meta|link|object)*, (title, (script|style|meta|link|object)*))))</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:head" "basis.html#xhtml1:head"
(define head (generate-html-surface-function xhtml1:head "head" (quote double)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>html</b> double tag element . <br>
;; .form (html . attributes-and-contents)
;; .parameter attributes-and-contents Element contents and attributes, as explained in the top of this manual.
;; .returns An instance of an abstract syntaxt tree.
;; .misc Required attributes: xmlns. <p>Optional attributes: lang, xml:lang, dir. <br><p><font size = 2>Content model: (head, body)</font>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "xhtml1:html" "basis.html#xhtml1:html"
(define html (generate-html-surface-function xhtml1:html "html" (quote double)))

